@@ -40,7 +40,6 @@ fields = dict(
     'minuptime', 'mindowntime',
     'startupramplimit', 'shutdownramplimit',
     #for a bid points defined gen, noloadcost replaces the constant polynomial
-    'costcurvepointsfilename',
     'noloadcost',
     'costcurveequation', 'heatrateequation',
     'fuelcost',
@@ -139,7 +138,14 @@ def parsedir(
     #add loads
     loads = build_class_list(loads_data, powersystems.Load, times, timeseries)
 
-    #add generators
+
+    # data modifiers
+    if user_config.pmin_multiplier != 1.0:
+        generators_data['pmin'] *= user_config.pmin_multiplier
+    if user_config.ramp_limit_multiplier != 1.0:
+        generators_data['rampratemin'] *= user_config.ramp_limit_multiplier
+        generators_data['rampratemax'] *= user_config.ramp_limit_multiplier
+
     if user_config.ignore_minhours_constraints:
         generators_data['minuptime'] = 0
         generators_data['mindowntime'] = 0
@@ -148,7 +154,9 @@ def parsedir(
         generators_data['rampratemin'] = None
     if user_config.ignore_pmin_constraints:
         generators_data['pmin'] = 0
-                
+
+        
+    # add generators    
     generators = build_class_list(generators_data, Generator, times, timeseries)
 
     #add lines
@@ -247,7 +255,8 @@ def build_class_list(data, model, times=None, timeseries=None):
 
         if is_generator:
             if schedulename or power or \
-                (forecast_name and user_config.deterministic_solve):
+                (forecast_name and user_config.deterministic_solve) or \
+                (observed_name and user_config.perfect_solve):
                 row_model = Generator_nonControllable
             elif scenariosdirectory or scenariosfilename:
                 row_model = Generator_Stochastic
@@ -278,7 +287,8 @@ def build_class_list(data, model, times=None, timeseries=None):
 
             if user_config.perfect_solve and observed_name:
                 # for a perfect information solve forecast = observed
-                kwds['schedule'] = timeseries[observed_name]
+                kwds['schedule'] = kwds['observed_values'] \
+                    = timeseries[observed_name]
             elif forecast_name:
                 kwds['schedule'] = timeseries[forecast_name]
 
@@ -293,7 +303,7 @@ def build_class_list(data, model, times=None, timeseries=None):
             if bid_points_filename:
                 kwds['bid_points'] = read_bid_points(
                     joindir(datadir, bid_points_filename))
-                row.costcurveequation = None
+                kwds['costcurveequation'] = None
 
         try:
             obj = row_model(index=i, **kwds)
@@ -308,8 +318,8 @@ def build_class_list(data, model, times=None, timeseries=None):
 
 def read_bid_points(filename):
     bid_points = read_csv(filename)
-    # return a tuple of bidpoints
-    return [ (bp['power'], bp['cost']) for bp in bid_points.iterrows()]
+    # return a dataframe of bidpoints
+    return bid_points[['power', 'cost']].astype(float)
 
 
 def setup_times(generators_data, loads_data, filename_timeseries):
@@ -343,7 +353,8 @@ def setup_times(generators_data, loads_data, filename_timeseries):
     for i, load in filter_notnull(loads_data, fcol).iterrows():
         name = 'd{}'.format(i)
         loads_data.ix[i, ncol] = name
-        timeseries[name] = get_schedule(joindir(datadir, load[fcol]))
+        timeseries[name] = get_schedule(joindir(datadir, load[fcol])) * \
+            user_config.load_multiplier
 
     for i, gen in filter_notnull(generators_data, fcol).iterrows():
         name = 'g{}'.format(i)
@@ -371,7 +382,10 @@ def setup_times(generators_data, loads_data, filename_timeseries):
             name = 'g{}_forecast'.format(i)
             generators_data.ix[i, fcstcol] = name
             timeseries[name] = get_schedule(joindir(datadir, gen[ffcstcol])) * \
-                user_config.wind_multiplier
+                user_config.wind_multiplier + user_config.wind_forecast_adder
+            if (timeseries[name]<0).any():
+                print timeseries[name].describe()
+                raise ValueError('wind forecast must always be at least zero')
         generators_data = generators_data.drop(ffcstcol, axis=1)
 
     generators_data = generators_data.drop(fcol, axis=1)
