@@ -295,11 +295,13 @@ class PowerSystem(OptimizationProblem):
     
     def total_scheduled_generation(self):
         return sum(gen.schedule for gen in self.generators() if not gen.is_controllable)    
+
+    def get_generators_noncontrollable(self):
+        return filter(lambda gen: not gen.is_controllable, self.generators())
         
     def get_generators_without_scenarios(self):
         return filter(lambda gen: getattr(gen,'is_stochastic',False)==False, self.generators())
 
-
     def get_generator_with_scenarios(self):
         gens = filter(lambda gen: getattr(gen,'is_stochastic',False), self.generators())
         if len(gens)>1: raise NotImplementedError('Dont handle the case of multiple stochastic generators')
@@ -362,6 +364,7 @@ class PowerSystem(OptimizationProblem):
         self._resolve_problem(sln)
         
         # re-store the generator outputs and costs
+        sln._resolved = True
         sln._get_outputs(resolve=True)
         sln._get_costs(resolve=True)
 
@@ -381,6 +384,7 @@ class PowerSystem(OptimizationProblem):
         self._resolve_problem(sln)
 
         # re-calc the generator outputs and costs
+        sln._resolved = True
         sln._get_outputs()
         sln._get_costs()
 
@@ -429,9 +433,8 @@ class PowerSystem(OptimizationProblem):
         # reset objective
         self._model.objective = None
         self.create_objective(const_times)
-        # re-create system cost constraints 
-        self.create_constraints(const_times, include_children=False)        
-
+        # re-create system cost constraints
+        self.create_constraints(const_times, include_children=False)
         # recreating all constraints would be simpler
         # but would take a bit longer
 
@@ -465,6 +468,7 @@ class PowerSystem(OptimizationProblem):
         
         # store original problem solve time
         self.full_sln_time = self.solution_time
+        full_mipgap = self.mipgap
         
         logging.info('resolving with observed values')
         try: self.solve()
@@ -480,8 +484,12 @@ class PowerSystem(OptimizationProblem):
                         sln.times, resolve_sln=sln)
                     raise
         
-        self.resolve_solution_time = self.solution_time
-        self.solution_time = self.full_sln_time
+        self.resolve_solution_time = float(self.solution_time)
+        self.solution_time = float(self.full_sln_time)
+        
+        if self.mipgap: self.mipgap_resolve = float(self.mipgap)
+        if full_mipgap: self.mipgap = float(full_mipgap)
+        
         logging.info('resolved instance with observed values (in {}s)'.format(
             self.resolve_solution_time))
 
