@@ -9,7 +9,7 @@ from collections import OrderedDict
 
 from commonscripts import (update_attributes, gen_time_dataframe, joindir,
     replace_all, getattrL, elementwiseAdd, writeCSV, transpose, within,
-    flatten, set_trace)
+    set_trace)
 from schedule import TimeIndex
 from optimization import value
 from config import user_config
@@ -112,10 +112,12 @@ class Solution(object):
             out = [value(getattr(obj, method)) for obj in items]
         return out
 
-    def gen_time_df(self, method, non_overlap=True, evaluate=False):
+    def gen_time_df(self, method, non_overlap=True, evaluate=False,
+        generators=None):
         times = self.times_non_overlap if non_overlap else self.times
-        return gen_time_dataframe(self.generators, times, 
-            [self.get_values(self.generators, method, t, evaluate) for t in times])
+        if generators is None: generators = self.generators
+        return gen_time_dataframe(generators, times, 
+            [self.get_values(generators, method, t, evaluate) for t in times])
 
     def _get_problem_info(self):
         self.solve_time = self.power_system.solution_time
@@ -139,7 +141,17 @@ class Solution(object):
         self.load_shed_timeseries = pd.Series(
             [sum(self.get_values(self.loads, 'shed', t, evaluate=True)) for t in times],
             index = times.strings.index)
+        self.gen_shed_timeseries = self.gen_time_df('shed', evaluate=True,
+            generators=self.power_system.get_generators_noncontrollable()
+            ).sum(axis=1)
+            
         self.load_shed = self.load_shed_timeseries.sum()
+        self.gen_shed = self.gen_shed_timeseries.sum()
+        
+        if self.gen_shed > 0.01:
+            logging.debug('generation shed: {}MW'.format(self.gen_shed))
+        if self.load_shed > 0.01:
+            logging.debug('load shed: {}MW'.format(self.load_shed))
         self._get_cost_error()
         
     def _get_cost_error(self):
@@ -310,7 +322,6 @@ class Solution_ED(Solution):
 
         if user_config.dispatch_decommit_allowed:
             # add status, but label all units at Pmin as OFF
-            Pmin = [gen.pmin for gen in self.generators]
             out['status'] = self.generators_status.ix[t]            
             out = out.drop('IC', axis=1)
 
@@ -412,7 +423,7 @@ class Solution_UC_multistage(Solution_UC):
         update_attributes(self, locals(),
             exclude=['stage_solutions', 'stage_times'])
         self._resolved = power_system.is_stochastic \
-            or user_config.deterministic_solve
+            or user_config.deterministic_solve or user_config.perfect_solve
 
         self.is_stochastic = any(sln.is_stochastic for sln in stage_solutions)
         
@@ -441,23 +452,22 @@ class Solution_UC_multistage(Solution_UC):
         if self._resolved:
             self.expected_power = self._concat('expected_power', slns)
             self.expected_status = self._concat('expected_status', slns)
-        elif user_config.perfect_solve:
-            self.expected_power = self.generators_power
-            self.expected_status = self.generators_status
+
 
     def _get_costs(self, slns):
         self.expected_cost = self.totalcost_generation = \
             self._concat('expected_totalcost' \
                 if self._resolved else 'totalcost_generation', slns)
         self.load_shed_timeseries = self._concat('load_shed_timeseries', slns)
+        self.gen_shed_timeseries = self._concat('gen_shed_timeseries', slns)
+
         self.load_shed = self.load_shed_timeseries.sum()
+        self.gen_shed = self.gen_shed_timeseries.sum()
 
         if self._resolved:
             self.observed_cost = self.totalcost_generation = \
                 self._concat('observed_totalcost', slns)
-        elif user_config.perfect_solve:
-            self.observed_cost = self.totalcost_generation = self.expected_cost
-
+                
 
     def info_cost(self):
         resolved = self._resolved
@@ -493,22 +503,27 @@ class Solution_UC_multistage(Solution_UC):
         return ['solved multistage problem in a total solver time ' + \
             'of {time:0.4f} sec'.format(time=self.solve_time)]
     def info_shedding(self):
-        return ['total load shed={}MW'.format(self.load_shed) \
-            if self.load_shed > 0.01 else '']
+        return [
+            'total load shed={}MW'.format(self.load_shed) \
+                if self.load_shed > 0.01 else '',
+            'total gen shed={}MW'.format(self.gen_shed) \
+                if self.gen_shed > 0.01 else '',
+            ]
 
 
 class MultistageStandalone(Solution_UC_multistage):
     def __init__(self, power_system, stage_times, store):
         self.power_system = power_system
         self.is_stochastic = power_system.is_stochastic
-        self._resolved = self.is_stochastic or user_config.deterministic_solve
+        self._resolved = self.is_stochastic or \
+            user_config.deterministic_solve or user_config.perfect_solve
         times = pd.concat([times.non_overlap().strings for times in stage_times]).index
         self.times=TimeIndex(times)
         self.times.set_initial(stage_times[0].initialTime)
 
         self.expected_cost = self.totalcost_generation = store['expected_cost']
 
-        if self._resolved or user_config.perfect_solve:
+        if self._resolved:
             self.observed_cost = self.totalcost_generation = \
                 store['observed_cost']
             
@@ -516,8 +531,11 @@ class MultistageStandalone(Solution_UC_multistage):
         self.generators_power = store['power']
         self.generators_status = store['status']
         self.load_shed_timeseries = store['load_shed']
-
+        self.gen_shed_timeseries = store['gen_shed']
+        
         self.load_shed = store['load_shed'].sum()
+        self.gen_shed = store['gen_shed'].sum()
+        
         self.solve_time = store['solve_time'].sum()
 
 
@@ -556,15 +574,18 @@ class Solution_Stochastic(Solution):
             major_axis = times.strings.index,
             minor_axis = [str(g) for g in self.generators])
 
-    def gen_time_df(self, method, scenario, non_overlap=True, evaluate=False):
+    def gen_time_df(self, method, scenario, non_overlap=True, evaluate=False,
+        generators=None):
+        if generators is None: generators = self.generators
+        
         if evaluate: 
             getval = lambda gen, t: value(getattr(gen, method)(t, scenario, evaluate=True))
         else:
             getval = lambda gen, t: value(getattr(gen, method)(t, scenario))
             
         times = self.times_non_overlap if non_overlap else self.times
-        return gen_time_dataframe(self.generators, times, 
-            [[getval(gen, t) for t in times] for gen in self.generators])
+        return gen_time_dataframe(generators, times, 
+            [[getval(gen, t) for t in times] for gen in generators])
 
 
     def _get_outputs(self, resolve=False):
@@ -610,12 +631,19 @@ class Solution_Stochastic(Solution):
                 self.gen_time_df('operatingcost', s, evaluate=True)
             
             #calc observed load shed            
-            if len(self.loads)>1: raise NotImplementedError
-            self.load_shed_timeseries = \
-                self.loads[0].schedule.ix[self.times_non_overlap].values - \
-                self.generators_power.sum(axis=1)
-                
+            if len(self.loads) > 1: raise NotImplementedError
+            self.load_shed_timeseries = pd.Series(
+                [self.power_system.loads()[0].shed(time, evaluate=True) 
+                    for time in self.times_non_overlap],
+                index=self.generators_power.index)
+            
+            self.gen_shed_timeseries = self.gen_time_df('shed', s, 
+                evaluate=True,
+                generators=self.power_system.get_generators_noncontrollable()
+                ).sum(axis=1)
+            
             self.load_shed = self.load_shed_timeseries.sum()
+            self.gen_shed = self.gen_shed_timeseries.sum()
             
         else: 
             # get expected cost of non_overlap times
