@@ -120,10 +120,13 @@ def solve_problem(datadir='.',
             solution.show()
             sys.stdout = stdout
         solution.show()
-    if csv: solution.saveCSV()
+    if csv and not user_config.standalone: solution.saveCSV()
     if user_config.visualization: solution.visualization()
-    # if solution_file: solution.save(solution_file)
     logging.info('total time: {}s'.format(timer.time()-start_time))
+
+    if user_config.on_complete_script:
+        os.system(user_config.on_complete_script)
+
     return solution
 
 
@@ -167,13 +170,9 @@ def create_solve_problem(power_system, times, scenario_tree=None,
     # resolve with observed power and fixed status
     if sln.is_stochastic:
         power_system.resolve_stochastic_with_observed(instance, sln)
-    elif user_config.deterministic_solve:
+    elif user_config.deterministic_solve or user_config.perfect_solve:
         power_system.resolve_determinisitc_with_observed(sln)
    
-    if sln.load_shed_timeseries.sum() > 0.01:
-        logging.debug('shed {}MW in resolve of stage'.format(
-            sln.load_shed_timeseries.sum()))
-
     if len(times)>1:
         power_system.get_finalconditions(sln)
 
@@ -270,10 +269,14 @@ def main():
     parser.add_argument('--dispatch_decommit_allowed', action="store_true",
         default=user_config.dispatch_decommit_allowed,
         help='flag to allow de-commitment of units in an ED -- useful for getting initial conditions for UCs')
-
-    parser.add_argument('--wind_multiplier', type=float,
-        default=user_config.wind_multiplier,
-        help='scale the wind power by this factor')
+    
+    parser.add_argument('--cost_wind_shedding', type=float,
+        default=user_config.cost_wind_shedding,
+        help='the cost to the system to shed a MWh of wind energy')
+    parser.add_argument('--cost_load_shedding', type=float,
+        default=user_config.cost_load_shedding,
+        help='the cost to the system to shed a MWh of load')
+        
     
     stochastic = parser.add_argument_group('Stochastic UC',
         'options to modify the behavior of a stochastic problem')
@@ -289,7 +292,7 @@ def main():
     stochastic_mode.add_argument('--deterministic_solve', '-D',
         action='store_true', default=user_config.deterministic_solve,
         help='solve a stochastic problem deterministically using the forecast_filename paramter')
-    stochastic_mode.add_argument('--perfect_solve', action='store_true',
+    stochastic_mode.add_argument('--perfect_solve', '-P', action='store_true',
         default=user_config.perfect_solve,  #False
         help='solve a stochastic problem with perfect information')
     stochastic_mode.add_argument('--scenarios_directory', type=str,
@@ -318,6 +321,19 @@ def main():
         default=False,
         help='run cProfile and output to minpower.profile')
     
+    ts = parser.add_argument_group('Timeseries modifiers',
+        'Alter the timeseries after parsing the data.')
+    ts.add_argument('--wind_multiplier', type=float,
+        default=user_config.wind_multiplier,
+        help='scale the wind power by this factor')
+    ts.add_argument('--wind_forecast_adder', type=float,
+        default=user_config.wind_forecast_adder,
+        help='add a fixed amount (e.g. bias) to the wind power forecast')
+    ts.add_argument('--load_multiplier', type=float,
+        default=user_config.load_multiplier,
+        help='scale the load power by this factor')
+    
+    
     constraints = parser.add_argument_group('Ignore/relax constraints',
         'Ignore or relax sets of constraints to allow for feasible solutions.')
     constraints.add_argument('--ignore_minhours_constraints', 
@@ -329,7 +345,18 @@ def main():
     constraints.add_argument('--ignore_pmin_constraints', 
         action="store_true", default=user_config.ignore_pmin_constraints,
         help='drop the min power constraints on the generators')
+    constraints.add_argument('--pmin_multiplier', type=float,
+        default=user_config.pmin_multiplier,
+        help='scale the generator minimum power limits by this factor')
+    constraints.add_argument('--ramp_limit_multiplier', type=float,
+        default=user_config.ramp_limit_multiplier,
+        help='scale the generator ramp power limits by this factor')
+
+
     
+    parser.add_argument('--on_complete_script', type=str, 
+        default=user_config.on_complete_script,
+        help='run a script on completion of the minpower script')
     # NOTE - don't let defaults creep into this defenition
     # that makes resetting the defaults during testing very hard 
 
