@@ -55,10 +55,13 @@ def init_store(power_system, times, data):
 
     # setup empty containers for variables
     storage['load_shed'] = Series()
+    storage['gen_shed'] = Series()
     storage['expected_cost'] = DataFrame()
     storage['observed_cost'] = DataFrame()
     storage['expected_status'] = DataFrame()
     storage['expected_power'] = DataFrame()
+    storage['expected_fuelcost'] = DataFrame()
+    storage['observed_fuelcost'] = DataFrame()
     
     # setup one-per-stage results
     storage['solve_time'] = Series(index=range(stages))
@@ -68,9 +71,23 @@ def init_store(power_system, times, data):
     storage['configuration'] = Series(user_config)
     
     
-    storage['version'] = Series({'minpower': 
-        pkg_resources.get_distribution('minpower').version})
+    storage['version'] = Series({
+        'minpower': pkg_resources.get_distribution('minpower').version,
+        # try storing version number of the current working directory 
+        'problem': _get_problem_version(),
+        })
+
+
     return storage
+
+def _get_problem_version():
+    version = None
+    possible_init = os.path.join(
+        os.path.abspath(user_config.directory), '__init__.py')
+    if os.path.exists(possible_init):
+        vstr = open(possible_init, 'r').read()
+        version = vstr.split('"')[1].rstrip('"')
+    return version
     
 def store_state(power_system, times, sln=None):
     storage = get_storage()
@@ -80,6 +97,7 @@ def store_state(power_system, times, sln=None):
     table_append(storage, 'power', sln.generators_power)
     table_append(storage, 'status', sln.generators_status)
     table_append(storage, 'load_shed', sln.load_shed_timeseries)
+    table_append(storage, 'gen_shed', sln.gen_shed_timeseries)
     
     tEnd = times.last_non_overlap()
     storage['hrsinstatus'] = gen_time_dataframe(generators, [tEnd], 
@@ -90,13 +108,16 @@ def store_state(power_system, times, sln=None):
     _add_tbl_val(storage, 'solve_time', stg, sln.solve_time)
     _add_tbl_val(storage, 'mipgap', stg, sln.mipgap)
     
-    if sln.is_stochastic or user_config.deterministic_solve:
+    if sln._resolved:
         table_append(storage, 'observed_cost', sln.observed_totalcost)
+        table_append(storage, 'observed_fuelcost', sln.observed_fuelcost)
         table_append(storage, 'expected_cost', sln.expected_totalcost)
+        table_append(storage, 'expected_fuelcost', sln.expected_fuelcost)
         table_append(storage, 'expected_power', sln.expected_power)
         table_append(storage, 'expected_status', sln.expected_status)
     else:
         table_append(storage, 'expected_cost', sln.totalcost_generation)
+        table_append(storage, 'expected_fuelcost', sln.fuelcost)
     return storage
     
 def load_state():
